@@ -12,9 +12,9 @@ import types
 
 # Provide a minimal RPi.GPIO mock ONLY when running under pytest
 # This ensures the mock is never activated outside of test execution
-if "pytest" in sys.modules or "_pytest" in sys.modules:
-    rpi = types.ModuleType("RPi")
-    gpio = types.ModuleType("RPi.GPIO")
+if 'pytest' in sys.modules or '_pytest' in sys.modules:
+    rpi = types.ModuleType('RPi')
+    gpio = types.ModuleType('RPi.GPIO')
 
     def _noop(*args, **kwargs):
         return None
@@ -37,7 +37,7 @@ if "pytest" in sys.modules or "_pytest" in sys.modules:
     gpio.LOW = 0
 
     # register modules so `import RPi.GPIO as GPIO` works
-    sys.modules["RPi"] = rpi
-    sys.modules["RPi.GPIO"] = gpio
+    sys.modules['RPi'] = rpi
+    sys.modules['RPi.GPIO'] = gpio
 
 # import pytest
